@@ -2,7 +2,7 @@ package PPI::Xref;
 
 require v5.10;  # For defined-or
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 use strict;
 use warnings;
@@ -722,7 +722,7 @@ sub __process_id {
                 my $sub = $elem->name;
                 unless ($sub =~ /::/) {  # sub x::y::z { ... }
                     $package //= 'main';
-                    $sub = "$package::$sub";
+                    $sub = $package . '::' . $sub;
                 }
                 my $finish = $elem->block->finish;
                 unless (defined $finish) {
